# theanonweather

A simple Python module that fetches real-time weather data using theanon.xyz API.

## Example

```python
from theanonweather import WeatherFetcher

fetcher = WeatherFetcher()
print(fetcher.get_weather("Pokhara"))
```
